@@ -41,12 +41,8 @@
 #include "update-notifier.h"
 #include "update.h"
 #include "hooks.h"
-#include "cdroms.h"
-#include "reboot.h"
 #include "uevent.h"
 #include "crash.h"
-#include "avahi.h"
-#include "release.h"
 #include "trayappletui.h"
 
 /* some prototypes */
@@ -69,18 +65,11 @@ static gboolean FORCE_PKEXEC=FALSE;
 // delay on startup (to make session startup faster)
 static int STARTUP_DELAY=1;
 
-// make the release upgrader check for a devel release
-gboolean DEVEL_RELEASE=FALSE;
-
-// force release check
-static gboolean FORCE_RELEASE_CHECK=FALSE;
-
 // global debug options
 static gboolean HOOK_DEBUG = FALSE;
 static gboolean UPDATE_DEBUG = FALSE;
 static gboolean INOTIFY_DEBUG = FALSE;
 static gboolean UEVENT_DEBUG = FALSE;
-static gboolean RELEASE_DEBUG = FALSE;
 static gboolean MISC_DEBUG = FALSE;
 
 // logging stuff
@@ -98,17 +87,13 @@ static void debug_log_handler (const gchar   *log_domain,
          g_log_default_handler (log_domain, log_level, message, user_data);
    }
    else if (log_domain && strcmp(log_domain, "inotify") == 0) {
-      if (INOTIFY_DEBUG) 
+      if (INOTIFY_DEBUG)
           g_log_default_handler (log_domain, log_level, message, user_data);
    }
    else if (log_domain && strcmp(log_domain, "uevent") == 0) {
       if (UEVENT_DEBUG)
          g_log_default_handler (log_domain, log_level, message, user_data);
    }
-   else if (log_domain && strcmp(log_domain, "release") == 0) {
-      if (RELEASE_DEBUG)
-         g_log_default_handler (log_domain, log_level, message, user_data);
-   }
    else if (MISC_DEBUG)
       g_log_default_handler (log_domain, log_level, message, user_data);
 }
@@ -193,6 +178,16 @@ invoke_with_pkexec(const gchar *cmd)
         g_spawn_async (NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, NULL, NULL);
 }
 
+void
+avahi_disabled()
+{
+        g_debug("avahi disabled ()");
+        gchar *argv[2];
+        argv[0] = "/usr/lib/update-notifier/local-avahi-notification";
+        argv[1] = NULL;
+        g_spawn_async (NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, NULL, NULL);
+}
+
 
 static gboolean
 trayapplet_create (TrayApplet *ta, UpgradeNotifier *un, char *name)
@@ -232,26 +227,22 @@ monitor_cb(GFileMonitor *handle,
    g_debug_inotify("event_type: %i",event_type);
 #endif
 
-   // we ignore lock file events because we can only get 
+   // we ignore lock file events because we can only get
    // when a lock was taken, but not when it was removed
    if(g_str_has_suffix(info_uri, "lock"))
       return;
 
    // look for apt-get install/update
-   if(g_str_has_prefix(info_uri,"/var/lib/apt/") 
+   if(g_str_has_prefix(info_uri,"/var/lib/apt/")
       || g_str_has_prefix(info_uri,"/var/cache/apt/")
       || strcmp(info_uri,"/var/lib/dpkg/status") == 0) {
       g_debug_inotify("apt_get_running=TRUE");
       un->apt_get_running=TRUE;
-   } 
+   }
    if(strstr(info_uri, "/var/lib/update-notifier/dpkg-run-stamp") ||
       strstr(info_uri, "/var/lib/apt/periodic/update-success-stamp")) {
       g_debug_inotify("dpkg_was_run=TRUE");
       un->dpkg_was_run = TRUE;
-   } 
-   if(strstr(info_uri, REBOOT_FILE)) {
-      g_debug_inotify("reboot required");
-      un->reboot_pending = TRUE;
    }
    if(strstr(info_uri, HOOKS_DIR)) {
       g_debug_inotify("new hook!");
@@ -273,8 +264,7 @@ monitor_cb(GFileMonitor *handle,
  * - dpkg_was_run=TRUE: set when apt wrote the "dpkg-run-stamp" file
  * - apt_get_running: set when apt/dpkg activity is detected (in the
  *                    lists-dir, archive-cache, or /var/lib/dpkg/status)
- * - hook_pending: we have new upgrade hoook information
- * - reboot_pending: we need to reboot
+ * - hook_pending: we have new upgrade hook information
  * - crashreport_pending: we have a new crashreport
  * - unicast_local_avahi_pending: avahi got disabled due to a unicast .local domain
  *
@@ -285,7 +275,7 @@ file_monitor_periodic_check(gpointer data)
    UpgradeNotifier *un = (UpgradeNotifier *)data;
 
    // we are not ready yet, wait for the next timeslice
-   if((un->reboot == NULL) || (un->crashreport == NULL))
+   if(un->crashreport == NULL)
       return TRUE;
 
    // DPkg::Post-Invoke has written a stamp file, that means an install/remove
@@ -313,12 +303,6 @@ file_monitor_periodic_check(gpointer data)
       update_apt_is_running(un->update, FALSE);
       if(un->update_finished_timer > 0) 
 	 g_source_remove(un->update_finished_timer);
-      
-      if(un->reboot_pending) {
-	 //g_print("checking reboot now\n");
-	 reboot_check (un->reboot);
-	 un->reboot_pending = FALSE;
-      }
 
       // apt must be finished when a new stamp file was written, so we
       // reset the apt_get_running time-slice field because its not
@@ -339,12 +323,12 @@ file_monitor_periodic_check(gpointer data)
 
    // apt-get update/install or dpkg is running (and updates files in
    // its list/cache dir) or in /var/lib/dpkg/status
-   if(un->apt_get_running) 
+   if(un->apt_get_running)
       update_apt_is_running(un->update, TRUE);
 
    // update time information for apt/dpkg
    time_t now = time(NULL);
-   if(un->apt_get_running) 
+   if(un->apt_get_running)
       un->last_apt_action = now;
 
    // no apt operation for a long time
@@ -363,7 +347,7 @@ file_monitor_periodic_check(gpointer data)
 
    if(un->unicast_local_avahi_pending) {
       g_debug("checking for disabled avahi due to unicast .local domain now");
-      avahi_disabled_check ();
+      avahi_disabled ();
       un->unicast_local_avahi_pending = FALSE;
    }
 
@@ -378,20 +362,23 @@ file_monitor_periodic_check(gpointer data)
 
 
 // FIXME: get the apt directories with apt-config or something
-static gboolean 
+static gboolean
 monitor_init(UpgradeNotifier *un)
 {
    int i;
    GFileMonitor *monitor_handle;
 
    // monitor these dirs
-   static const char *monitor_dirs[] = { 
-      "/var/lib/apt/lists/", "/var/lib/apt/lists/partial/", 
-      "/var/cache/apt/archives/", "/var/cache/apt/archives/partial/", 
-      HOOKS_DIR, 
+   static const char *monitor_dirs[] = {
+      "/var/lib/apt/lists/", "/var/lib/apt/lists/partial/",
+      "/var/cache/apt/archives/", "/var/cache/apt/archives/partial/",
+      HOOKS_DIR,
       CRASHREPORT_DIR,
       NULL};
    for(i=0;monitor_dirs[i] != NULL;i++) {
+      if (getenv("UPSTART_SESSION") && monitor_dirs[i] == CRASHREPORT_DIR) {
+         continue;
+      }
       GError *error = NULL;
       GFile *gf = g_file_new_for_path(monitor_dirs[i]);
       monitor_handle = g_file_monitor_directory(gf, 0, NULL, &error);
@@ -402,14 +389,16 @@ monitor_init(UpgradeNotifier *un)
    }
 
    // and those files
-   static const char *monitor_files[] = { 
-      "/var/lib/dpkg/status", 
-      "/var/lib/update-notifier/dpkg-run-stamp", 
+   static const char *monitor_files[] = {
+      "/var/lib/dpkg/status",
+      "/var/lib/update-notifier/dpkg-run-stamp",
       "/var/lib/apt/periodic/update-success-stamp",
-      REBOOT_FILE,
       UNICAST_LOCAL_AVAHI_FILE,
       NULL};
    for(i=0;monitor_files[i] != NULL;i++) {
+      if (getenv("UPSTART_SESSION") && monitor_files[i] == UNICAST_LOCAL_AVAHI_FILE) {
+         continue;
+      }
       GError *error = NULL;
       GFile *gf = g_file_new_for_path(monitor_files[i]);
       monitor_handle = g_file_monitor_file(gf, 0, NULL, &error);
@@ -441,7 +430,7 @@ tray_icons_init(UpgradeNotifier *un)
    if (in_admin_group() || FORCE_START) {
       trayapplet_create(un->update, un, "software-update-available");
       update_tray_icon_init(un->update);
-   } else 
+   } else
       un->update = NULL;
 
    /* update hook icon*/
@@ -449,11 +438,6 @@ tray_icons_init(UpgradeNotifier *un)
    trayapplet_create(un->hook, un, "hook-notifier");
    hook_tray_icon_init(un->hook);
 
-   /* reboot required icon */
-   un->reboot = g_new0 (TrayApplet, 1);
-   trayapplet_create(un->reboot, un, "un-reboot");
-   reboot_tray_icon_init(un->reboot);
-
    /* crashreport detected icon */
    un->crashreport = g_new0 (TrayApplet, 1);
    trayapplet_create(un->crashreport, un, "apport");
@@ -465,7 +449,7 @@ tray_icons_init(UpgradeNotifier *un)
 static gboolean
 system_user(UpgradeNotifier *un)
 {
-   /* do not start for system users, e.g. the guest session 
+   /* do not start for system users, e.g. the guest session
     * (see /usr/share/gdm/guest-session/guest-session-setup.sh)
     */
    int end_system_uid = 500;
@@ -499,14 +483,14 @@ user_in_group(const char* grpname)
      free (groups);
      return 1;
    }
-   
+
    for(i=0;i<ng;i++) {
       if(groups[i] == grp->gr_gid) {
         free(groups);
         return 1;
       }
    }
-   
+
    if(groups != NULL)
       free(groups);
 
@@ -534,33 +518,30 @@ sigint_cb (gpointer user_data __attribute__ ((__unused__)))
 }
 
 
-static GOptionEntry entries[] = 
+static GOptionEntry entries[] =
 {
    { "debug-hooks", 0, 0, G_OPTION_ARG_NONE, &HOOK_DEBUG, "Enable hooks debugging"},
    { "debug-updates", 0, 0, G_OPTION_ARG_NONE, &UPDATE_DEBUG, "Enable updates/autolaunch debugging"},
    { "debug-inotify", 0, 0, G_OPTION_ARG_NONE, &INOTIFY_DEBUG, "Enable inotify debugging"},
    { "debug-uevent", 0, 0, G_OPTION_ARG_NONE, &UEVENT_DEBUG, "Enable uevent debugging"},
-   { "debug-new-release-check", 0, 0, G_OPTION_ARG_NONE, &RELEASE_DEBUG, "Enable new release check debugging"},
    { "debug-misc", 0, 0, G_OPTION_ARG_NONE, &MISC_DEBUG, "Enable uncategorized debug prints"},
    { "force", 0, 0, G_OPTION_ARG_NONE, &FORCE_START, "Force start even if the user is not in the admin group"},
    { "force-use-pkexec", 0, 0, G_OPTION_ARG_NONE, &FORCE_PKEXEC, "Force running all commands (update-manager, synaptic) with pkexec" },
    { "startup-delay", 0, 0, G_OPTION_ARG_INT, &STARTUP_DELAY, "Delay startup by given amount of seconds" },
-   { "devel-release", 0, 0, G_OPTION_ARG_NONE, &DEVEL_RELEASE, "Make the release checker check for a new development release" },
-   { "force-release-check", 0, 0, G_OPTION_ARG_NONE, &FORCE_RELEASE_CHECK, "Force release check" },
    { NULL }
 };
 
-int 
+int
 main (int argc, char **argv)
 {
 	UpgradeNotifier *un;
 	GError *error = NULL;
 
 	// init
-	if(!gtk_init_with_args (&argc, &argv, 
-				_("- inform about updates"), entries, 
+	if(!gtk_init_with_args (&argc, &argv,
+				_("- inform about updates"), entries,
 				"update-notifier", &error) ) {
-	   fprintf(stderr, _("Failed to init the UI: %s\n"), 
+	   fprintf(stderr, _("Failed to init the UI: %s\n"),
 		   error ? error->message : _("unknown error"));
 	   exit(1);
 	}
@@ -571,7 +552,7 @@ main (int argc, char **argv)
         textdomain(PACKAGE);
 
 	if (HOOK_DEBUG || UPDATE_DEBUG || INOTIFY_DEBUG ||
-	    UEVENT_DEBUG || RELEASE_DEBUG || MISC_DEBUG)
+	    UEVENT_DEBUG || MISC_DEBUG)
 		g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
 
 	// setup a custom debug log handler
@@ -583,8 +564,6 @@ main (int argc, char **argv)
 			   debug_log_handler, NULL);
 	g_log_set_handler ("uevent", G_LOG_LEVEL_DEBUG,
 			   debug_log_handler, NULL);
-	g_log_set_handler ("release", G_LOG_LEVEL_DEBUG,
-			   debug_log_handler, NULL);
 	g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG,
 			   debug_log_handler, NULL);
 
@@ -603,10 +582,6 @@ main (int argc, char **argv)
 	   exit(0);
 	}
 
-	// do not run as system user (e.g. guest user)
-	if (FORCE_RELEASE_CHECK)
-	   g_settings_reset(un->settings, SETTINGS_KEY_LAST_RELEASE_CHECK);
-
 	// check if it is running already
 	if (!up_get_clipboard ()) {
 	   g_warning ("already running?");
@@ -620,25 +595,15 @@ main (int argc, char **argv)
 	   g_mkdir(dirname, 0700);
 	g_free(dirname);
 
-	// delay icon creation for 30s so that the desktop 
+	// delay icon creation for 30s so that the desktop
 	// login is not slowed down by update-notifier
-	g_timeout_add_seconds(STARTUP_DELAY, 
+	g_timeout_add_seconds(STARTUP_DELAY,
 			      (GSourceFunc)(tray_icons_init), un);
 
-        // initial check for avahi
-        avahi_disabled_check();
-
-	/* setup inserted-cdroms checker */
-	if(!cdroms_init(un)) {
-	   g_warning("initializing cdroms failed");
-	}
-
-	// init release checker
-	release_checker_init(un);
-
-	// init uevent monitoring (missing firmware, etc.)
+	// init uevent monitoring (printer support, etc.)
+#ifdef ENABLE_SCP
 	uevent_init();
-
+#endif
 	// init gio file monitoring
 	monitor_init (un);
 
