@@ -174,10 +174,8 @@ update_apt_is_running(TrayApplet *ta, gboolean is_running)
    UpdateTrayAppletPrivate *priv = (UpdateTrayAppletPrivate*)ta->user_data;
    priv->apt_is_running = is_running;
 
-   // if the user wants auto-launch mode, do not show the icon
-   // the auto launch stuff will do its magic later
-   if(g_settings_get_boolean(ta->un->settings, SETTINGS_KEY_AUTO_LAUNCH))
-      return;
+   // everybody wants auto-launch mode
+   return;
 
    if(is_running) {
 #ifdef HAVE_APP_INDICATOR
@@ -642,18 +640,13 @@ update_check (TrayApplet *ta)
    // update the tooltip
    update_trayicon_update_tooltip(ta, priv->num_upgrades);
 
-   // check if the user wants to see the icon or launch
-   // the default action
-   if(g_settings_get_boolean(ta->un->settings, SETTINGS_KEY_AUTO_LAUNCH))
+   tray_applet_ui_set_visible(ta, FALSE);
+   if (auto_launch_now(ta))
    {
-      tray_applet_ui_set_visible(ta, FALSE);
-      if (auto_launch_now(ta)) 
-      {
-	 g_spawn_command_line_async("nice ionice -c3 update-manager "
-				    "--no-update --no-focus-on-map", NULL);
-      }
-      return TRUE;
+      g_spawn_command_line_async("nice ionice -c3 update-manager "
+			         "--no-update --no-focus-on-map", NULL);
    }
+   return TRUE;
 
    // if we are already visible, skip the rest
    if(tray_applet_ui_get_visible (ta))
